@@ -160,7 +160,6 @@ def trace_evm_call(
     trace_call_resp = web3.manager.request_blocking("trace_call", [tx, ["trace"], block_reference])
 
 
-
 def print_symbolic_trace(
     contract_registry: ContractRegistry,
     calltree: CallTreeNode,
@@ -286,8 +285,8 @@ def assert_transaction_success_with_explanation(
 
 
 def assert_call_success_with_explanation(
-        func: ContractFunction,
-        transaction: Optional[TxParams] = None,
+    func: ContractFunction,
+    transaction: Optional[TxParams] = None,
 ) -> Any:
     """Make a Web3.call and if it fails get the Solidity stack trace.
 
@@ -370,7 +369,7 @@ class SymbolicTreeRepresentation:
             # Ignore checksumming if user does not have eth-hash backend installed.
             address = cast(ChecksumAddress, address_hex_str)
 
-        contract = self.contract_registry.get(address)
+        contract = self.contract_registry.get(address.lower())
 
         function_selector = self.call.calldata[:4]
 
