@@ -110,7 +110,7 @@ def deploy_uniswap_v3(
     """
     # Factory takes feeSetter as an argument
     factory = deploy_uniswap_v3_factory(web3, deployer)
-    weth = deploy_contract(web3, "WETH9Mock.json", deployer)
+    weth = deploy_contract(web3, "sushi/WETH9Mock.json", deployer)
     swap_router = deploy_contract(
         web3,
         "uniswap_v3/SwapRouter.json",
@@ -418,7 +418,7 @@ def fetch_deployment(
 
     # https://github.com/Uniswap/v3-periphery/blob/6cce88e63e176af1ddb6cc56e029110289622317/contracts/SwapRouter.sol#L40
     weth_address = router.functions.WETH9().call()
-    weth = get_deployed_contract(web3, "WETH9Mock.json", weth_address)
+    weth = get_deployed_contract(web3, "sushi/WETH9Mock.json", weth_address)
 
     return UniswapV3Deployment(
         web3=web3,
